pub enum MplAgentToolsError {
Show 15 variants
InvalidSystemProgram,
InvalidInstructionData,
InvalidAccountData,
InvalidMplCoreProgram,
InvalidCoreAsset,
ExecutiveProfileMustBeUninitialized,
InvalidExecutionDelegateRecordDerivation,
ExecutionDelegateRecordMustBeUninitialized,
InvalidAgentIdentity,
AgentIdentityNotRegistered,
AssetOwnerMustBeTheOneToDelegateExecution,
InvalidExecutiveProfileDerivation,
ExecutionDelegateRecordMustBeInitialized,
UnauthorizedRevoke,
ExecutiveProfileMustBeInitialized,
}Variants
InvalidSystemProgram
0 (0x0) - Invalid System Program
InvalidInstructionData
1 (0x1) - Invalid instruction data
InvalidAccountData
2 (0x2) - Invalid account data
InvalidMplCoreProgram
3 (0x3) - Invalid MPL Core Program
InvalidCoreAsset
4 (0x4) - Invalid Core Asset
ExecutiveProfileMustBeUninitialized
5 (0x5) - Executive Profile must be uninitialized
InvalidExecutionDelegateRecordDerivation
6 (0x6) - Invalid Execution Delegate Record Derivation
ExecutionDelegateRecordMustBeUninitialized
7 (0x7) - Execution Delegate Record must be uninitialized
InvalidAgentIdentity
8 (0x8) - Invalid Agent Identity
AgentIdentityNotRegistered
9 (0x9) - Agent Identity not registered
AssetOwnerMustBeTheOneToDelegateExecution
10 (0xA) - Asset owner must be the one to delegate execution
InvalidExecutiveProfileDerivation
11 (0xB) - Invalid Executive Profile Derivation
ExecutionDelegateRecordMustBeInitialized
12 (0xC) - Execution Delegate Record must be initialized
13 (0xD) - Authority must be asset owner or executive to revoke
ExecutiveProfileMustBeInitialized
14 (0xE) - Executive Profile must be initialized